Learn R Programming

rwavelet (version 0.4.2)

CircularShift: Circular Shifting of a matrix/image

Description

Pixels that get shifted off one side of the image are put back on the other side.

Usage

CircularShift(matrix, colshift = 0, rowshift = 0)

Value

result 2-d shifted signal.

Arguments

matrix

2-d signal (matrix).

colshift

column shift index (integer).

rowshift

row shift index (integer).

See Also

FWT2_TI, IWT2_TI.

Examples

Run this code
A <- matrix(1:4, ncol=2, byrow=TRUE)
CircularShift(A, 0, -1)

Run the code above in your browser using DataLab